<p align="center">
    <img src="session/towns-of-malaya.jpg" alt="malaya logo" />
</p>

# Malaya
Natural-Language-Toolkit for bahasa Malaysia, powered by Deep Learning.

## Features

* Entities Recognition
* Language Detection
* Normalizer
* Num2Word
* Part-of-Speech Recognition
* Sentiment Analysis
* Spell Correction
* Stemmer
* Summarization
* Topic Modelling
* Topic and Influencers Analysis
* Toxicity Analysis
* Word2Vec

## How-to-Start

All the documentations moved to [Malaya Wiki](https://github.com/DevconX/Malaya/wiki).

## Contributors

* **Husein Zolkepli** - *Initial work* - [huseinzol05](https://github.com/huseinzol05)

* **Sani** - *build PIP package* - [khursani8](https://github.com/khursani8)
